#  Copyright (c) 2021 Mira Geoscience Ltd.
#
#  This file is part of geoh5py.
#
#  geoh5py is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  geoh5py is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with geoh5py.  If not, see <https://www.gnu.org/licenses/>.

import uuid
from typing import Optional

from .group import Group, GroupType


class CustomGroup(Group):
    """A custom group, for an unlisted Group type."""

    _name = "Custom"
    _description = "Custom"

    def __init__(self, group_type: GroupType, **kwargs):
        assert group_type is not None
        super().__init__(group_type, **kwargs)

        if self.entity_type.name == "Entity":
            self.entity_type.name = "Custom Group"

        group_type.workspace._register_group(self)

    @classmethod
    def default_type_uid(cls) -> Optional[uuid.UUID]:
        raise RuntimeError(f"No predefined static type UUID for {cls}.")
        # return None
